# booking-sites-parser
Parser for booking sites such as Booking.com, Homeaway.com, Airbnb.com

## Usage
The parser can be executed via the command line. 

**Examples:**

python -m booking_sites_parser 'https://www.airbnb.co.uk/rooms/plus/29702349' 'https://www.airbnb.co.uk/rooms/530250'

booking-sites-parser 'https://www.airbnb.co.uk/rooms/plus/29702349' 'https://www.airbnb.co.uk/rooms/530250'
